@@ -48,7 +48,7 @@ class SDTransactionFailed(Exception):
     pass
 
 
-class Usb2642(object):
+class Usb2642:
     """
     This class provides an interface to interact with devices on a Microchip
     USB2642 auxiliary I2C Bus and to write configuration to an EEPROM on the
@@ -333,7 +333,7 @@ class Usb2642(object):
         command -- SCSI Command payload to send. 16-Byte buffer containing the SCSI
                    command parameters.
         sg_dxfer -- _SG_DXFER_*: Direction of the SCSI transfer
-        databuffer -- 512 byte long buffer to be written oder read
+        databuffer -- 512 byte long buffer to be written or read
         """
         sgio, sense = self._get_SGIO(command, sg_dxfer, databuffer)
         #    print("SGIO:")
@@ -342,7 +342,7 @@ class Usb2642(object):
         with open(self.sg, "r+b", buffering=0) as fh:
             rc = fcntl.ioctl(fh, self._SG_IO, sgio)
             if rc != 0:
-                raise IoctlFailed("SG_IO ioctl() failed with non-zero exit-code {}".format(rc))
+                raise IoctlFailed(f"SG_IO ioctl() failed with non-zero exit-code {rc}")
         return databuffer, sense, sgio
 
     def write_config(self, data):
@@ -390,7 +390,7 @@ class Usb2642(object):
         * writeData[1]
         * ...
         * I2C-Repeated Start
-        * I2C-Slave address wit R/W = R (1)
+        * I2C-Slave address with R/W = R (1)
         * readData[0]
         * readData[1]
         * ...
@@ -417,7 +417,7 @@ class Usb2642(object):
 
         if sgio.status != 0:
             raise I2cTransactionFailed(
-                "SCSI-Transaction ended with status {}. I2C-Transaction has probably failed.".format(sgio.status)
+                f"SCSI-Transaction ended with status {sgio.status}. I2C-Transaction has probably failed."
             )
 
         return list(data[:readLength])
@@ -453,7 +453,7 @@ class Usb2642(object):
 
         if sgio.status != 0:
             raise I2cTransactionFailed(
-                "SCSI-Transaction ended with status {}. I2C-Transaction has probably failed.".format(sgio.status)
+                f"SCSI-Transaction ended with status {sgio.status}. I2C-Transaction has probably failed."
             )
 
     def _read_register(self, reg, size, retries=5):
@@ -472,7 +472,7 @@ class Usb2642(object):
 
             if sgio.status != 0:
                 raise SDTransactionFailed(
-                    "SCSI Transaction ended with status {}. SD Transaction has probably failed.".format(sgio.status)
+                    f"SCSI Transaction ended with status {sgio.status}. SD Transaction has probably failed."
                 )
 
             break
