@@ -21,8 +21,8 @@
 import os
 import time
 
-from .i2c_gpio import Pca9536, Tca6408
 from . import sd_regs
+from .i2c_gpio import Pca9536, Tca6408
 
 
 class UnknownUsbSdMuxRevisionException(Exception):
@@ -45,7 +45,7 @@ def autoselect_driver(sg):
     sg_name = os.path.basename(base_sg)
     model_filename = f"/sys/class/scsi_generic/{sg_name}/device/model"
     try:
-        with open(model_filename, "r") as fh:
+        with open(model_filename) as fh:
             model = fh.read().strip()
         if model == "sdmux HS-SD/MMC":
             return UsbSdMuxClassic(sg)
@@ -217,8 +217,8 @@ class UsbSdMuxFast(UsbSdMux):
     _card_inserted = 0x00
     _card_removed = Tca6408.gpio_3
 
-    gpio0 = Tca6408.gpio_4
-    gpio1 = Tca6408.gpio_5
+    gpio0 = Tca6408.gpio_5
+    gpio1 = Tca6408.gpio_4
 
     def __init__(self, sg):
         self._tca = Tca6408(sg)
